@@ -1,4 +1,7 @@
+# Load configuration
+from . import config
 from ._version import __version__
+from .auth import BasicAuth, JupyterHubAuth, KerberosAuth
 from .client import (
     Gateway,
     GatewayCluster,
@@ -6,10 +9,6 @@ from .client import (
     GatewayServerError,
     GatewayWarning,
 )
-from .auth import KerberosAuth, BasicAuth, JupyterHubAuth
 from .options import Options
 
-# Load configuration
-from . import config
-
 del config
